@@ -16,7 +16,7 @@ int main (int argc, char **argv)
 	gtk_init (&argc, &argv);
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_widget_set_size_request (window, 740, -1);
+	gtk_widget_set_size_request (window, 740, 490);
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	g_signal_connect (G_OBJECT (window), "delete-event",
 			  G_CALLBACK (delete_event_cb), NULL);
